@@ -1,12 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "sdml-mode" "0.2.0"
+(define-package "sdml-mode" "20251013.2205"
   "Major mode for SDML."
   '((emacs              "28.1")
     (tree-sitter        "0.18.0")
     (tree-sitter-indent "0.4"))
   :url "https://github.com/johnstonskj/emacs-sdml-mode"
-  :commit "1f59deffa3186a9eafe3921fdb793549a4629a03"
-  :revdesc "v0.2.0-0-g1f59deffa318"
+  :commit "67daad6f56b0c2fa796d7708a790101492d14b79"
+  :revdesc "67daad6f56b0"
   :keywords '("languages" "tools")
   :authors '(("Simon Johnston" . "johnstonskj@gmail.com"))
   :maintainers '(("Simon Johnston" . "johnstonskj@gmail.com")))
